Struct hedera::AssessedCustomFee
source · pub struct AssessedCustomFee {
pub amount: i64,
pub token_id: Option<TokenId>,
pub fee_collector_account_id: Option<AccountId>,
pub payer_account_id_list: Vec<AccountId>,
}Expand description
A custom transfer fee that was assessed during the handling of a CryptoTransfer.
Fields
amount: i64The amount of currency charged to each payer.
token_id: Option<TokenId>The currency amount is charged in, if None the fee is in HBar.
fee_collector_account_id: Option<AccountId>The account that receives the fees that were charged.
payer_account_id_list: Vec<AccountId>A list of all accounts that were charged this fee.
Implementations
sourceimpl AssessedCustomFee
impl AssessedCustomFee
sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self>
pub fn from_bytes(bytes: &[u8]) -> Result<Self>
Create a new AssessedCustomFee from protobuf-encoded bytes.
Errors
Error::FromProtobufif decoding the bytes fails to produce a valid protobuf.Error::FromProtobufif decoding the protobuf fails.