Struct hedera::ScheduleInfo
source · pub struct ScheduleInfo {
pub schedule_id: ScheduleId,
pub creator_account_id: AccountId,
pub payer_account_id: Option<AccountId>,
pub signatories: KeyList,
pub admin_key: Option<Key>,
pub scheduled_transaction_id: TransactionId,
pub wait_for_expiry: bool,
pub memo: String,
pub expiration_time: Option<OffsetDateTime>,
pub executed_at: Option<OffsetDateTime>,
pub deleted_at: Option<OffsetDateTime>,
pub ledger_id: LedgerId,
/* private fields */
}Expand description
Response from ScheduleInfoQuery.
Fields
schedule_id: ScheduleIdThe ID of the schedule for which information is requested.
creator_account_id: AccountIdThe account that created the scheduled transaction.
payer_account_id: Option<AccountId>The account paying for the execution of the scheduled transaction.
signatories: KeyListThe signatories that have provided signatures so far for the schedule transaction.
admin_key: Option<Key>The key which is able to delete the schedule transaction if set.
scheduled_transaction_id: TransactionIdThe transaction id that will be used in the record of the scheduled transaction (if it executes).
wait_for_expiry: boolWhen set to true, the transaction will be evaluated for execution at expiration_time
instead of when all required signatures are received.
memo: StringPublicly visible information about the Schedule entity.
expiration_time: Option<OffsetDateTime>The date and time the schedule transaction will expire
executed_at: Option<OffsetDateTime>The time the schedule transaction was executed.
deleted_at: Option<OffsetDateTime>The time the schedule transaction was deleted.
ledger_id: LedgerIdThe ledger ID the response was returned from
Implementations
sourceimpl ScheduleInfo
impl ScheduleInfo
sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self>
pub fn from_bytes(bytes: &[u8]) -> Result<Self>
Create a new ScheduleInfo from protobuf-encoded bytes.
Errors
Error::FromProtobufif decoding the bytes fails to produce a valid protobuf.Error::FromProtobufif decoding the protobuf fails.
sourcepub fn scheduled_transaction(&self) -> Result<AnyTransaction>
pub fn scheduled_transaction(&self) -> Result<AnyTransaction>
Returns the scheduled transaction.
This is not guaranteed to be a constant time operation.