Struct hedera::TopicMessage
source · #[non_exhaustive]pub struct TopicMessage {
pub consensus_timestamp: OffsetDateTime,
pub contents: Vec<u8>,
pub running_hash: Vec<u8>,
pub running_hash_version: u64,
pub sequence_number: u64,
pub chunks: Option<Vec<TopicMessageChunk>>,
pub transaction: Option<TransactionId>,
}Expand description
Topic message records.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.consensus_timestamp: OffsetDateTimeThe consensus timestamp of the message.
If there are multiple chunks, this is taken from the last chunk.
contents: Vec<u8>The content of the message.
running_hash: Vec<u8>The new running hash of the topic that received the message.
If there are multiple chunks, this is taken from the last chunk.
running_hash_version: u64Version of the SHA-384 digest used to update the running hash.
If there are multiple chunks, this is taken from the last chunk.
sequence_number: u64The sequence number of the message relative to all other messages for the same topic.
If there are multiple chunks, this is taken from the last chunk.
chunks: Option<Vec<TopicMessageChunk>>The chunks that make up this message.
transaction: Option<TransactionId>The TransactionId of the first chunk, gets copied to every subsequent chunk in the message.